/**
 * scanhack.c - Program to test out driver interaction code.
 *
 * @authors Joe Kopena tjkopena@cs.drexel.edu 2004/06
 **/

#include <stdio.h>
#include <string.h>
#include <unistd.h>

#include <usb.h>

#include "scannerlib.h"

#define INIT_FILE   "init"

#define STROBE_VENDOR   0x04a7
#define STROBE_PRODUCT  0x0427

#define DEFAULT_TIMEOUT 500

#define NUM_ENDPOINTS    3
int endpoints[NUM_ENDPOINTS] = { 0x81, 0x82, 0x03 };

#define PAPER_IN        0x01
#define PAPER_INSERTED  0x08
#define BUTTON_DOWN     0x10

#define MAX_FILES       7


int main(int argc, char *argv[]) {
   usb_dev_handle *udev;
   unsigned char nowait = 0;
   int ret, i;

   for (i = 0; i < argc; i++) {
     if (!strcmp(argv[i], "-nw"))
       nowait = 1;

     // end for each argv
   }

   sysInit();
   udev = xp100Find();
   if (!udev)
     return -1;

   if ((ret = xp100Init(udev)) < 0)
     return ret;

   // Now we are all setup to do stuff

   if (!nowait)
     if ((ret = xp100WaitForPaperReady(udev)) < 0)
       return ret;

   // if ((ret = xp100Scan(udev)) < 0)
   //     return ret;
   if ((ret = xp100ParametricScan(udev,
				  "test.ppm",
				  4,
				  2, 0,
				  0,
				  3)) < 0)
     return ret;

   // Now bop out
   xp100Kill(udev);
   sysKill();

   /* end main*/
   return 0;
}
